@@ -109,6 +109,7 @@
 
 #include <X11/Xos.h>
 #include <X11/Xlib.h>
+#include <X11/Intrinsic.h>
 #include <X11/Xutil.h>
 #ifndef NO_WIN_UTIL_H
 #include <X11/Xmu/WinUtil.h>
@@ -122,43 +123,24 @@
 /*add include for signal for sunOS benefit *kob*/
 #include <signal.h>
 
-
-
-typedef unsigned long Pixel;
-
 #define FEEP_VOLUME 0
 
-/* Include routines to do parsing */
-#include "dsimple.h"
+#include "ferret.h"
+#include "FerMem.h"
 
 /* Setable Options */
 
-int format = ZPixmap;
-Bool nobdrs = False;
-Bool on_root = False;
-Bool standard_out = True;
-Bool debug = False;
-Bool use_installed = False;
-long add_pixel_value = 0;
+static int format = ZPixmap;
+static Bool on_root = False;
+/* static Bool debug = False; */
+static Bool use_installed = False;
+static long add_pixel_value = 0;
 
-extern int (*_XErrorFunction)();
-extern int _XDefaultError();
+static int Get_XColors(XWindowAttributes *win_info, XImage *image, XColor **colors, Display *dpy);
 
-
-static long parse_long (s)
-    char *s;
+static int endian_type (void)
 {
-    char *fmt = "%lu";
-    long retval = 0L;
-    int thesign = 1;
-
-    if (s && s[0]) {
-	if (s[0] == '-') s++, thesign = -1;
-	if (s[0] == '0') s++, fmt = "%lo";
-	if (s[0] == 'x' || s[0] == 'X') s++, fmt = "%lx";
-	(void) sscanf (s, fmt, &retval);
-    }
-    return (thesign * retval);
+  return (*(short *) "AZ")& 255;
 }
 
 /*
@@ -166,32 +148,18 @@ static long parse_long (s)
  *              writting.
  */
 
-/* calloc defined in stdlib.h 
-  char *calloc();
-  */
-
-/* #include "X11/XWDFile.h" */
-
-Window_Dump(window, dpy,outfile, type)
-     Window window;
-     Display *dpy;
-     char *outfile;
-     char *type;
+void Window_Dump(Window window, Display *dpy, char *outfile, char *type)
 {
-    unsigned long swaptest = 1;
-    XColor *colors;
-    unsigned buffer_size;
-    int win_name_size;
-    int header_size;
+    XColor *colors = NULL;
     int ncolors, i;
     char *win_name;
     Bool got_win_name;
     XWindowAttributes win_info;
     XImage *image;
+    int screen = 0;
     int absx, absy, x, y;
     unsigned width, height;
     int dwidth, dheight;
-    int bw;
     Window dummywin;
     int *r, *g, *b;
     void (*func)();
@@ -206,13 +174,6 @@ Window_Dump(window, dpy,outfile, type)
     func = signal(SIGIO, SIG_DFL);
 #endif
 
-
-
-    /*
-     * Inform the user not to alter the screen.
-     */
-/*    Beep(); */
-
     /*
      * Get the parameters of the window being dumped.
      */
@@ -231,8 +192,8 @@ Window_Dump(window, dpy,outfile, type)
     if (!XTranslateCoordinates (dpy, window, RootWindow (dpy, screen), 0, 0,
 				&absx, &absy, &dummywin)) {
 	fprintf (stderr, 
-		 "%s:  unable to translate window coordinates (%d,%d)\n",
-		 program_name, absx, absy);
+		 "unable to translate window coordinates (%d,%d)\n",
+		 absx, absy);
 #ifdef HP_SIGNALS
 	signal(_SIGIO, func);
 #else
@@ -244,19 +205,7 @@ Window_Dump(window, dpy,outfile, type)
     win_info.y = absy;
     width = win_info.width;
     height = win_info.height;
-    bw = 0;
 
-/* If borders are taken into account with unmapped windows, things crash. 
-   this check on borders in xwd code not needed here.  
-   if (!nobdrs) {
-	absx -= win_info.border_width;
-	absy -= win_info.border_width;
-	bw = win_info.border_width;
-	width += (2 * bw);
-	height += (2 * bw);
-	}
-
-*/
     dwidth = DisplayWidth (dpy, screen);
     dheight = DisplayHeight (dpy, screen);
 
@@ -275,9 +224,6 @@ Window_Dump(window, dpy,outfile, type)
 	got_win_name = True;
     }
 
-    /* sizeof(char) is included for the null string terminator. */
-    win_name_size = strlen(win_name) + sizeof(char);
-
     /*
      * Snarf the pixmap with XGetImage.
      */
@@ -299,8 +245,8 @@ Window_Dump(window, dpy,outfile, type)
       image = XGetImage (dpy, window, x, y, width, height, AllPlanes, format);
 
     if (!image) {
-	fprintf (stderr, "%s:  unable to get image at %dx%d+%d+%d\n",
-		 program_name, width, height, x, y);
+	fprintf (stderr, "unable to get image at %dx%d+%d+%d\n",
+		 width, height, x, y);
 #ifdef HP_SIGNALS
 	signal(_SIGIO, func);
 #else
@@ -311,11 +257,6 @@ Window_Dump(window, dpy,outfile, type)
 
     if (add_pixel_value != 0) XAddPixel (image, add_pixel_value);
 
-    /*
-     * Determine the pixmap size.
-     */
-    buffer_size = Image_Size(image);
-
 /*     if (debug) outl("xwd: Getting Colors.\n");*/
 
     ncolors = Get_XColors(&win_info, image, &colors,dpy); 
@@ -334,9 +275,9 @@ Window_Dump(window, dpy,outfile, type)
     XFlush(dpy);
 #endif
 
-    r = (int *)malloc(sizeof(int) * ncolors);
-    g = (int *)malloc(sizeof(int) * ncolors);
-    b = (int *)malloc(sizeof(int) * ncolors); 
+    r = (int *)FerMem_Malloc(sizeof(int) * ncolors, __FILE__, __LINE__);
+    g = (int *)FerMem_Malloc(sizeof(int) * ncolors, __FILE__, __LINE__);
+    b = (int *)FerMem_Malloc(sizeof(int) * ncolors, __FILE__, __LINE__); 
     for (i=0; i < ncolors; i++) {
       r[i] = colors[i].red;
       g[i] = colors[i].green;
@@ -357,7 +298,14 @@ Window_Dump(window, dpy,outfile, type)
 
 /*    if(debug && ncolors > 0) outl("xwd: Freeing colors.\n"); */
 /* *kob* 5/96 - also free the arrays r,g,b */
-    if(ncolors > 0) free(colors);free(r); free(g); free(b);
+    FerMem_Free(colors, __FILE__, __LINE__);
+    colors = NULL;
+    FerMem_Free(r, __FILE__, __LINE__); 
+    r = NULL;
+    FerMem_Free(g, __FILE__, __LINE__); 
+    g = NULL;
+    FerMem_Free(b, __FILE__, __LINE__);
+    b = NULL;
 
     /*
      * Free window name string.
@@ -386,66 +334,18 @@ Window_Dump(window, dpy,outfile, type)
     XDestroyImage(image);
 }
 
-/*
- * Report the syntax for calling xwd.
- */
-/*usage()
-{
-    fprintf (stderr,
-"usage: %s [-display host:dpy] [-debug] [-help] %s [-nobdrs] [-out <file>]",
-	   program_name, SELECT_USAGE);
-    fprintf (stderr, " [-kludge] [-xy] [-add value] [-frame]\n");
-    exit(1);
-}
-*/
-
-/*
- * Error - Fatal xwd error.
- */
-extern int errno;
-
-Error(string)
-	char *string;	/* Error description string. */
-{
-/*	outl("\nxwd: Error => %s\n", string); */
-	if (errno != 0) {
-		perror("xwd");
-	/*outl("\n"); */
-	} exit(1);
-}
-
-
-/*
- * Determine the pixmap size.
- */
-
-int Image_Size(image)
-     XImage *image;
-{
-    if (image->format != ZPixmap)
-      return(image->bytes_per_line * image->height * image->depth);
-
-    return(image->bytes_per_line * image->height);
-}
-
 #define lowbit(x) ((x) & (~(x) + 1))
 #define lowbyte(x) ((x) & (~(x) + 8))
 
 /*
  * Get the XColors of all pixels in image - returns # of colors
  */
-int Get_XColors(win_info, image, colors,dpy) 
-     XImage *image;  
-     XWindowAttributes *win_info;
-     XColor **colors;
-     Display *dpy;
+static int Get_XColors(XWindowAttributes *win_info, XImage *image, XColor **colors, Display *dpy) 
 {
     int i, ncolors;
     unsigned long pixel;
     unsigned char *cptr,tmp_cptr;
 
-    Pixel pmask = 0xff000000;
-
     Bool reverse_bytes;
 
     Colormap cmap = win_info->colormap;
@@ -460,17 +360,17 @@ int Get_XColors(win_info, image, colors,dpy)
     /* ncolors = win_info->visual->map_entries;*/
     ncolors = 256;
 
-    if (!(*colors = (XColor *) malloc (sizeof(XColor) * ncolors)))
-      {
+    *colors = (XColor *) FerMem_Malloc(sizeof(XColor) * ncolors, __FILE__, __LINE__);
+    if ( *colors == NULL ) {
 	fprintf (stderr, "Fatal Error - Out of memory!");
 	exit (1);
-      }
+    }
 
     if (win_info->visual->class == DirectColor ||
 	win_info->visual->class == TrueColor) {
 
 	int nunique_colors;
-	char ind; 
+	int ind; 
 	char *color_indices =  (char *) image->data;
 	unsigned int *color_values = (unsigned int *) image->data;
 	/*	int npixels = image->bytes_per_line * image->height; */
@@ -506,18 +406,18 @@ int Get_XColors(win_info, image, colors,dpy)
 	  /* see if this pixel matches a known color index */
 	  ind = 0;
 
-	  while ( (ind < (int) nunique_colors) 
+	  while ( (ind < nunique_colors) 
                && (color_values[i] != (*colors)[ind].pixel) ) ind++;
 
 	  /* store unique color just found */
-	  if (ind == (int)nunique_colors ) {
+	  if (ind == nunique_colors ) {
 	    (*colors)[ind].pixel = color_values[i]; 
 	    nunique_colors++;
 	  }  
 
 	  /* replace color with index pointer in image structure */
 	  /* (Read the image as color_values.  Write it as color_indices) */
-	  color_indices[i] = ind; 
+	  color_indices[i] = (char) ind; 
 	}	  
 	
 
@@ -529,7 +429,6 @@ int Get_XColors(win_info, image, colors,dpy)
 
 	/* need to test the blue mask to see which endianness machine we are on. 
 	   then grab the individual rgb values from the pixel value */
-	/*	for (i=0; i<= nunique_colors; i++) { */
 
 	if ( endian_type() == 65 ) {
 	  if (ImageByteOrder(dpy))
@@ -581,44 +480,3 @@ int Get_XColors(win_info, image, colors,dpy)
     return(ncolors);
 }
 
-_swapshort (bp, n)
-    register char *bp;
-    register unsigned n;
-{
-    register char c;
-    register char *ep = bp + n;
-
-    while (bp < ep) {
-	c = *bp;
-	*bp = *(bp + 1);
-	bp++;
-	*bp++ = c;
-    }
-}
-
-_swaplong (bp, n)
-    register char *bp;
-    register unsigned n;
-{
-    register char c;
-    register char *ep = bp + n;
-    register char *sp;
-
-    while (bp < ep) {
-	sp = bp + 3;
-	c = *sp;
-	*sp = *bp;
-	*bp++ = c;
-	sp = bp + 1;
-	c = *sp;
-	*sp = *bp;
-	*bp++ = c;
-	bp += 2;
-    }
-}
-
-
-int endian_type ()
-{
-  return (*(short *) "AZ")& 255;
-}
