@@ -40,15 +40,12 @@
  */
 
 #include <stdlib.h>
+#include "ferret.h"
+#include "FerMem.h"
 
-void set_null_c_string_(out_ptr)
-     char** out_ptr;
+void FORTRAN(set_null_c_string)(char **out_ptr)
 {
-   if ( *out_ptr != NULL )
-      free(*out_ptr);
-
-   *out_ptr = (char *) malloc(sizeof(char));
-   if ( *out_ptr == NULL )
-      abort();
-   **out_ptr = '\0';
+   if ( (*out_ptr != NULL) && (*out_ptr != STRING_MISSING_VALUE) )
+      FerMem_Free(*out_ptr, __FILE__, __LINE__);
+   *out_ptr = STRING_MISSING_VALUE;
 }
